@@ -26,11 +26,18 @@ check_PD <- function(vcov_list) {
 
 #' Impute a block-diagonal covariance matrix
 #'
-#' @description \code{impute_covariance_matrix} calculates a
-#'   block-diagonal covariance matrix, given the marginal variances, the block
-#'   structure, and an assumed correlation structure. Can be used to create
-#'   compound-symmetric structures, AR(1) auto-correlated structures, or
-#'   combinations thereof.
+#' @description `r lifecycle::badge("superseded")`
+#'
+#'   This function is superseded by the \code{\link[metafor]{vcalc}} provided by
+#'   the \code{metafor} package. Compared to \code{impute_covariance_matrix},
+#'   \code{\link[metafor]{vcalc}} provides many further features, includes a
+#'   \code{data} argument, and uses syntax that is consistent with other
+#'   functions in \code{metafor}.
+#'
+#'   \code{impute_covariance_matrix} calculates a block-diagonal covariance
+#'   matrix, given the marginal variances, the block structure, and an assumed
+#'   correlation structure. Can be used to create compound-symmetric structures,
+#'   AR(1) auto-correlated structures, or combinations thereof.
 #'
 #' @param vi Vector of variances
 #' @param cluster Vector indicating which effects belong to the same cluster.
@@ -68,35 +75,36 @@ check_PD <- function(vcov_list) {
 #' @details A block-diagonal variance-covariance matrix (possibly represented as
 #'   a list of matrices) with a specified structure. The structure depends on
 #'   whether the \code{r} argument, \code{ar1} argument, or both arguments are
-#'   specified. Let \eqn{v_{ij}}{v-ij} denote the specified variance for
-#'   effect \eqn{i}{i} in cluster \eqn{j}{j} and \eqn{C_{hij}}{C-hij} be
-#'   the covariance between effects \eqn{h}{h} and \eqn{i}{i} in cluster
-#'   \eqn{j}{j}. \itemize{ \item{If only \code{r} is specified,}{ each block
-#'   of the variance-covariance matrix will have a constant (compound symmetric)
-#'   correlation, so that \deqn{C_{hij} = r_j \sqrt{v_{hj} v_{ij},}}{C-hij =
-#'   r-j * sqrt(v-hj v-ij),} where \eqn{r_j}{r-j} is the specified correlation
+#'   specified. Let \eqn{v_{ij}}{v-ij} denote the specified variance for effect
+#'   \eqn{i}{i} in cluster \eqn{j}{j} and \eqn{C_{hij}}{C-hij} be the covariance
+#'   between effects \eqn{h}{h} and \eqn{i}{i} in cluster
+#'   \eqn{j}{j}. 
+#'   \itemize{ 
+#'   \item{If only \code{r} is specified, each block of the variance-covariance 
+#'   matrix will have a constant (compound symmetric) correlation, so that 
+#'   \deqn{C_{hij} = r_j \sqrt{v_{hj} v_{ij},}}{C-hij = r-j * sqrt(v-hj v-ij),} 
+#'   where \eqn{r_j}{r-j} is the specified correlation
 #'   for cluster \eqn{j}{j}. If only a single value is given in \code{r}, then
-#'   it will be used for every cluster.} \item{If only \code{ar1} is
-#'   specified,}{ each block of the variance-covariance matrix will have an
-#'   AR(1) auto-correlation structure, so that \deqn{C_{hij} = \phi_j^{|t_{hj}
-#'   - t_{ij}|} \sqrt{v_{hj} v_{ij},}}{C-hij = (ar1-j)^|t-hj - t-ij| * sqrt(v-hj
-#'   v-ij),} where \eqn{\phi_j}{ar1-j} is the specified auto-correlation
+#'   it will be used for every cluster.} 
+#'   \item{If only \code{ar1} is specified, each block of the variance-covariance matrix will have an
+#'   AR(1) auto-correlation structure, so that 
+#'   \deqn{C_{hij} = \phi_j^{|t_{hj}- t_{ij}|} \sqrt{v_{hj} v_{ij},}}{C-hij = (ar1-j)^|t-hj - t-ij| * sqrt(v-hj v-ij),} 
+#'   where \eqn{\phi_j}{ar1-j} is the specified auto-correlation
 #'   for cluster \eqn{j}{j} and \eqn{t_{hj}}{t-hj} and \eqn{t_{ij}}{t-ij}
 #'   are specified time-points corresponding to effects \eqn{h}{h} and
 #'   \eqn{i}{i} in cluster \eqn{j}{j}. If only a single value is given in
-#'   \code{ar1}, then it will be used for every cluster.} \item{If both \code{r}
-#'   and \code{ar1} are specified,}{ each block of the variance-covariance
-#'   matrix will have combination of compound symmetric and an AR(1)
-#'   auto-correlation structures, so that \deqn{C_{hij} = \left[r_j + (1 -
-#'   r_j)\phi_j^{|t_{hj} - t_{ij}|}\right] \sqrt{v_{hj} v_{ij},}}{C-hij = [r-j +
-#'   (1 - r-j)(ar1-j)^|t-hj - t-ij|] * sqrt(v-hj v-ij),} where
-#'   \eqn{r_j}{r-j} is the specified constant correlation for cluster
+#'   \code{ar1}, then it will be used for every cluster.} 
+#'   \item{If both \code{r} and \code{ar1} are specified, each block of the variance-covariance matrix will have combination of compound symmetric and an AR(1)
+#'   auto-correlation structures, so that 
+#'   \deqn{C_{hij} = \left[r_j + (1 - r_j)\phi_j^{|t_{hj} - t_{ij}|}\right] \sqrt{v_{hj} v_{ij},}}{C-hij = [r-j + (1 - r-j)(ar1-j)^|t-hj - t-ij|] * sqrt(v-hj v-ij),} 
+#'   where \eqn{r_j}{r-j} is the specified constant correlation for cluster
 #'   \eqn{j}{j}, \eqn{\phi_j}{ar1-j} is the specified auto-correlation for
 #'   cluster \eqn{j}{j} and \eqn{t_{hj}}{t-hj} and \eqn{t_{ij}}{t-ij} are
 #'   specified time-points corresponding to effects \eqn{h}{h} and
 #'   \eqn{i}{i} in cluster \eqn{j}{j}. If only single values are given in
-#'   \code{r} or \code{ar1}, they will be used for every cluster.} } If
-#'   \code{smooth_vi = TRUE}, then all of the variances within cluster
+#'   \code{r} or \code{ar1}, they will be used for every cluster.} 
+#'   } 
+#'   If \code{smooth_vi = TRUE}, then all of the variances within cluster
 #'   \eqn{j}{j} will be set equal to the average variance of cluster
 #'   \eqn{j}{j}, i.e., \deqn{v'_{ij} = \frac{1}{n_j} \sum_{i=1}^{n_j}
 #'   v_{ij}}{v-ij' = (v-1j + ... + v-nj,j) / n-j} for
@@ -105,9 +113,9 @@ check_PD <- function(vcov_list) {
 #' @export
 #'
 #' @examples
-#' 
+#'
 #' if (requireNamespace("metafor", quietly = TRUE)) {
-#' 
+#'
 #' library(metafor)
 #'
 #' # Constant correlation
@@ -115,7 +123,7 @@ check_PD <- function(vcov_list) {
 #' V_list <- impute_covariance_matrix(vi = SATcoaching$V, cluster = SATcoaching$study, r = 0.66)
 #' MVFE <- rma.mv(d ~ 0 + test, V = V_list, data = SATcoaching)
 #' conf_int(MVFE, vcov = "CR2", cluster = SATcoaching$study)
-#' 
+#'
 #' }
 #' 
 
@@ -126,6 +134,8 @@ impute_covariance_matrix <- function(vi, cluster, r, ti, ar1,
                                      return_list = identical(as.factor(cluster), sort(as.factor(cluster))),
                                      check_PD = TRUE) {
   
+  lifecycle::deprecate_soft("0.5.11", "impute_covariance_matrix()", "metaffor::vcalc()")
+  
   cluster <- droplevels(as.factor(cluster))
   
   vi_list <- split(vi, cluster)
@@ -188,6 +198,14 @@ impute_covariance_matrix <- function(vi, cluster, r, ti, ar1,
 
 #' Impute a patterned block-diagonal covariance matrix
 #'
+#' @description `r lifecycle::badge("superseded")`
+#'
+#'   This function is superseded by the \code{\link[metafor]{vcalc}} provided by
+#'   the \code{metafor} package. Compared to \code{pattern_covariance_matrix},
+#'   \code{\link[metafor]{vcalc}} provides many further features, includes a
+#'   \code{data} argument, and uses syntax that is consistent with other
+#'   functions in \code{metafor}.
+#'
 #' @description \code{pattern_covariance_matrix} calculates a
 #'   block-diagonal covariance matrix, given the marginal variances, the block
 #'   structure, and an assumed correlation structure defined by a patterned
@@ -283,6 +301,8 @@ pattern_covariance_matrix <- function(vi, cluster, pattern_level, r_pattern, r,
                                      return_list = identical(as.factor(cluster), sort(as.factor(cluster))),
                                      check_PD = TRUE) {
   
+  lifecycle::deprecate_soft("0.5.11", "impute_covariance_matrix()", "metaffor::vcalc()")
+  
   if (missing(pattern_level)) stop("You must specify a vector for pattern_level.")
   if (any(is.na(pattern_level[!is.na(vi)]))) stop("The pattern_level vector cannot have missing values.")
   
@@ -346,7 +366,7 @@ pattern_covariance_matrix <- function(vi, cluster, pattern_level, r_pattern, r,
 # vcovCR with defaults
 #-------------------------------------
 
-#' Cluster-robust variance-covariance matrix for a robu object.
+#' Cluster-robust variance-covariance matrix for a rma.mv object.
 #' 
 #' \code{vcovCR} returns a sandwich estimate of the variance-covariance matrix 
 #' of a set of regression coefficient estimates from a 
